@@ -1,6 +1,6 @@
 ######################################################################
 #
-# makealldists.pl - make all dists
+# makealldists.pl - make all encoding distributions from Char
 #
 # Copyright (c) 2010, 2011, 2012, 2013, 2015 INABA Hitoshi <ina@cpan.org>
 #
@@ -9,7 +9,7 @@
 use strict;
 use File::Copy;
 
-my @dist = (
+my @encoding = (
     'Sjis',
     'USASCII',
     'UTF2',
@@ -46,14 +46,14 @@ my @dist = (
     'Windows1258',
 );
 
-for my $dist (@dist) {
+for my $encoding (@encoding) {
     sleep(1);
-    mkdir($dist,0777);
+    mkdir($encoding,0777);
 
     open(TEST,">test.pl") || die "Can't open file: test.pl, q(;_;)bad!!\n";
     binmode TEST;
     print TEST <<END;
-# encoding: $dist;
+# encoding: $encoding;
 use Char;
 
 \$| = 1;
@@ -67,7 +67,7 @@ END
     open(TEST,">test.pl") || die "Can't open file: test.pl, q(;_;)bad!!\n";
     binmode TEST;
     print TEST <<END;
-use $dist;
+use $encoding;
 
 \$| = 1;
 print "1..1\\n";
@@ -78,13 +78,13 @@ END
     mysystem(q{perl test.pl});
 
     for my $file (
-        "$dist.pm",
-        "E\L$dist\E.pm",
+        "$encoding.pm",
+        "E\L$encoding\E.pm",
         'test.pl',
         'Changes',
         'pMakefile.PL',
     ){
-        mycopy($file, "$dist/$file");
+        mycopy($file, "$encoding/$file");
     }
 
     for my $file (
@@ -94,27 +94,26 @@ END
     ) {
         open(FILE1,$file) || die "Can't open file: $file, q(;_;)bad!!\n";
         binmode FILE1;
-        open(FILE2,">$dist/$file") || die "Can't open file: $dist/$file, q(;_;)bad!!\n";
+        open(FILE2,">$encoding/$file") || die "Can't open file: $encoding/$file, q(;_;)bad!!\n";
         binmode FILE2;
         while (<FILE1>) {
-            s!Character Oriented Perl by Magic Comment!Source code filter to escape $dist script!;
-            s!# encoding: [^ \n]+!# encoding: $dist!;
-            s!\bChar\b!$dist!g;
-            s! \s* 'test' \s* => \s* \{ \s* 'TESTS' \s* => \s* 't/\*/\*\.t' \s* \} \s* , \s* $!!x;
+            s!Character Oriented Perl by Magic Comment!Source code filter to escape $encoding script!;
+            s!# encoding: [^ \n]+!# encoding: $encoding!;
+            s!\bChar\b!$encoding!g;
             print FILE2 $_;
         }
         close(FILE1);
         close(FILE2);
     }
 
-    mycopy("README2ND/README2ND.$dist","$dist/README2ND");
+    mycopy("README2ND/README2ND.$encoding","$encoding/README2ND");
 
-    mkdir("$dist/Char",0777);
-    open(FILE,">$dist/Char/$dist.pm") || die "Can't open file: $dist/Char/$dist.pm, q(;_;)bad!!\n";
+    mkdir("$encoding/Char",0777);
+    open(FILE,">$encoding/Char/$encoding.pm") || die "Can't open file: $encoding/Char/$encoding.pm, q(;_;)bad!!\n";
     binmode FILE;
     print FILE <<END;
 # This is a dummy file to implement CPAN naming goals.
-package Char::$dist;
+package Char::$encoding;
 
 # On The Naming of Modules/NAMES TO AVOID/Top-level namespaces
 # https://pause.perl.org/pause/query?ACTION=pause_namingmodules#Top_level_namespaces
@@ -125,12 +124,12 @@ __END__
 END
     close(FILE);
 
-    open(MANIFEST,">$dist/MANIFEST") || die "Can't open file: $dist/MANIFEST, q(;_;)bad!!\n";
-    binmode MANIFEST;
+    open(ENCODING_MANIFEST,">$encoding/MANIFEST") || die "Can't open file: $encoding/MANIFEST, q(;_;)bad!!\n";
+    binmode ENCODING_MANIFEST;
     for my $file (
-        "Char/$dist.pm",
-        "$dist.pm",
-        "E\L$dist\E.pm",
+        "Char/$encoding.pm",
+        "$encoding.pm",
+        "E\L$encoding\E.pm",
         'README',
         'Changes',
         'META.yml',
@@ -140,12 +139,37 @@ END
         'README2ND',
         'MANIFEST',
     ) {
-        check_usascii("$dist/$file");
-        print MANIFEST $file, "\n";
+        check_usascii("$encoding/$file");
+        print ENCODING_MANIFEST $file, "\n";
     }
-    close(MANIFEST);
 
-    mychdir($dist);
+    open(CHAR_MANIFEST,'MANIFEST') || die "Can't open file: MANIFEST, q(;_;)bad!!\n";
+    binmode CHAR_MANIFEST;
+    mkdir("$encoding/t", 0777);
+    mkdir("$encoding/t/$encoding", 0777);
+    while (my $file = <CHAR_MANIFEST>) {
+        chomp $file;
+        if ($file =~ m{^x?t/$encoding/.*\.t$}) {
+            print ENCODING_MANIFEST $file, "\n";
+            open(FILE1,$file) || die "Can't open file: $file, q(;_;)bad!!\n";
+            binmode FILE1;
+            (my $file2 = $file) =~ s#^xt/#t/#;
+            open(FILE2,">$encoding/$file2") || die "Can't open file: $encoding/$file2, q(;_;)bad!!\n";
+            binmode FILE2;
+            while (<FILE1>) {
+                s!# encoding: [^ \n]+!# encoding: $encoding!;
+                s!\bChar\b!$encoding!g;
+                print FILE2 $_;
+            }
+            close(FILE1);
+            close(FILE2);
+        }
+    }
+    close(CHAR_MANIFEST);
+
+    close(ENCODING_MANIFEST);
+
+    mychdir($encoding);
     mysystem(q{perl pMakefile.PL});
     if ($^O eq 'MSWin32') {
         mysystem(q{pmake.bat dist});
@@ -194,3 +218,46 @@ sub check_usascii {
 }
 
 __END__
+
+=pod
+
+=head1 NAME
+
+makealldists.pl - make all encoding distributions from Char
+
+=head1 SYNOPSIS
+
+  perl makealldists.pl
+
+=head1 DEPENDENCIES
+
+This software requires perl5.00503 or later.
+
+=head1 AUTHOR
+
+INABA Hitoshi E<lt>ina@cpan.orgE<gt>
+
+This project was originated by INABA Hitoshi.
+
+=head1 LICENSE AND COPYRIGHT
+
+This software is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
+This software is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+
+=head1 SEE ALSO
+
+ CPAN Directory INABA Hitoshi
+ http://search.cpan.org/~ina/
+
+ BackPAN
+ http://backpan.perl.org/authors/id/I/IN/INA/
+
+ Recent Perl packages by "INABA Hitoshi"
+ http://code.activestate.com/ppm/author:INABA-Hitoshi/
+
+=cut
+
